@@ -16,6 +16,7 @@ from typing import (
 
 import attr
 import fs
+import fs.base
 import fs.tempfs
 from fontTools.ufoLib import UFOFileStructure, UFOReader, UFOWriter
 
@@ -28,8 +29,13 @@ from ufoLib2.objects.imageSet import ImageSet
 from ufoLib2.objects.info import Info
 from ufoLib2.objects.layer import Layer
 from ufoLib2.objects.layerSet import LayerSet
-from ufoLib2.objects.misc import BoundingBox, _deepcopy_unlazify_attrs
-from ufoLib2.typing import PathLike, T
+from ufoLib2.objects.misc import (
+    BoundingBox,
+    _deepcopy_unlazify_attrs,
+    _object_lib,
+    _prune_object_libs,
+)
+from ufoLib2.typing import HasIdentifier, PathLike, T
 
 
 def _convert_Info(value: Union[Info, Mapping[str, Any]]) -> Info:
@@ -124,7 +130,7 @@ class Font:
     """Info: The font Info object."""
 
     features: Features = attr.ib(
-        factory=Features, converter=_convert_Features, kw_only=True,
+        factory=Features, converter=_convert_Features, kw_only=True
     )
     """Features: The font Features object."""
 
@@ -138,13 +144,11 @@ class Font:
     lib: Dict[str, Any] = attr.ib(factory=dict, kw_only=True)
     """Dict[str, Any]: A mapping of keys to arbitrary values."""
 
-    data: DataSet = attr.ib(
-        factory=DataSet, converter=_convert_DataSet, kw_only=True,
-    )
+    data: DataSet = attr.ib(factory=DataSet, converter=_convert_DataSet, kw_only=True)
     """DataSet: A mapping of data file paths to arbitrary data."""
 
     images: ImageSet = attr.ib(
-        factory=ImageSet, converter=_convert_ImageSet, kw_only=True,
+        factory=ImageSet, converter=_convert_ImageSet, kw_only=True
     )
     """ImageSet: A mapping of image file paths to arbitrary image data."""
 
@@ -174,7 +178,7 @@ class Font:
                 self._reader = reader
 
     @classmethod
-    def open(cls, path: PathLike, lazy: bool = True, validate: bool = True,) -> "Font":
+    def open(cls, path: PathLike, lazy: bool = True, validate: bool = True) -> "Font":
         """Instantiates a new Font object from a path to a UFO.
 
         Args:
@@ -217,7 +221,7 @@ class Font:
             self._reader = reader
         return self
 
-    def __contains__(self, name: str) -> bool:
+    def __contains__(self, name: object) -> bool:
         return name in self.layers.defaultLayer
 
     def __delitem__(self, name: str) -> None:
@@ -303,7 +307,7 @@ class Font:
         return not result
 
     @property
-    def reader(self) -> UFOReader:
+    def reader(self) -> Optional[UFOReader]:
         """Returns the underlying :class:`fontTools.ufoLib.UFOReader`."""
         return self._reader
 
@@ -368,6 +372,27 @@ class Font:
         for guideline in value:
             self.appendGuideline(guideline)
 
+    def objectLib(self, object: HasIdentifier) -> Dict[str, Any]:
+        """Return the lib for an object with an identifier, as stored in a font's lib.
+
+        If the object does not yet have an identifier, a new one is assigned to it. If
+        the font lib does not yet contain the object's lib, a new one is inserted and
+        returned.
+
+        .. doctest::
+
+            >>> from ufoLib2.objects import Font, Guideline
+            >>> font = Font()
+            >>> font.guidelines = [Guideline(x=100)]
+            >>> guideline_lib = font.objectLib(font.guidelines[0])
+            >>> guideline_lib["com.test.foo"] = 1234
+            >>> guideline_id = font.guidelines[0].identifier
+            >>> assert guideline_id is not None
+            >>> assert font.lib["public.objectLibs"][guideline_id] is guideline_lib
+        """
+
+        return _object_lib(self.lib, object)
+
     @property
     def path(self) -> Optional[PathLike]:
         """Return the path of the UFO, if it was set, or None."""
@@ -476,6 +501,10 @@ class Font:
         writer.writeGroups(self.groups)
         writer.writeInfo(self.info)
         writer.writeKerning(self.kerning)
+        _prune_object_libs(
+            self.lib,
+            {g.identifier for g in self.guidelines if g.identifier is not None},
+        )
         writer.writeLib(self.lib)
         # save the layers
         self.layers.write(writer, saveAs=saveAs)
