@@ -1,15 +1,5 @@
 from copy import deepcopy
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    Iterator,
-    List,
-    Mapping,
-    Optional,
-    Tuple,
-    Union,
-)
+from typing import Any, Dict, Iterator, List, Mapping, Optional, Tuple, Union
 
 import attr
 from fontTools.misc.transform import Transform
@@ -25,11 +15,9 @@ from ufoLib2.objects.component import Component
 from ufoLib2.objects.contour import Contour
 from ufoLib2.objects.guideline import Guideline
 from ufoLib2.objects.image import Image
-from ufoLib2.objects.misc import BoundingBox, getBounds, getControlBounds
+from ufoLib2.objects.misc import BoundingBox, _object_lib, getBounds, getControlBounds
 from ufoLib2.pointPens.glyphPointPen import GlyphPointPen
-
-if TYPE_CHECKING:
-    from ufoLib2.objects.layer import Layer  # noqa: F401
+from ufoLib2.typing import GlyphSet, HasIdentifier
 
 
 @attr.s(auto_attribs=True, slots=True, repr=False)
@@ -216,6 +204,28 @@ class Glyph:
                 color=image.get("color"),
             )
 
+    def objectLib(self, object: HasIdentifier) -> Dict[str, Any]:
+        """Return the lib for an object with an identifier, as stored in a glyph's lib.
+
+        If the object does not yet have an identifier, a new one is assigned to it. If
+        the font lib does not yet contain the object's lib, a new one is inserted and
+        returned.
+
+        .. doctest::
+
+            >>> from ufoLib2.objects import Font, Guideline
+            >>> font = Font()
+            >>> glyph = font.newGlyph("a")
+            >>> glyph.guidelines = [Guideline(x=100)]
+            >>> guideline_lib = glyph.objectLib(glyph.guidelines[0])
+            >>> guideline_lib["com.test.foo"] = 1234
+            >>> guideline_id = glyph.guidelines[0].identifier
+            >>> assert guideline_id is not None
+            >>> assert glyph.lib["public.objectLibs"][guideline_id] is guideline_lib
+        """
+
+        return _object_lib(self.lib, object)
+
     def clear(self) -> None:
         """Clears out anchors, components, contours, guidelines and image
         references."""
@@ -279,7 +289,7 @@ class Glyph:
     def appendContour(self, contour: Contour) -> None:
         """Appends a :class:`.Contour` object to glyph's list of contours."""
         if not isinstance(contour, Contour):
-            raise TypeError(f"Expected Contour, found {type(contour).__name__}",)
+            raise TypeError(f"Expected Contour, found {type(contour).__name__}")
         self.contours.append(contour)
 
     def copy(self, name: Optional[str] = None) -> "Glyph":
@@ -397,7 +407,7 @@ class Glyph:
 
     # bounds and side-bearings
 
-    def getBounds(self, layer: Optional["Layer"] = None) -> Optional[BoundingBox]:
+    def getBounds(self, layer: Optional[GlyphSet] = None) -> Optional[BoundingBox]:
         """Returns the (xMin, yMin, xMax, yMax) bounding box of the glyph,
         taking the actual contours into account.
 
@@ -411,7 +421,7 @@ class Glyph:
         return getBounds(self, layer)
 
     def getControlBounds(
-        self, layer: Optional["Layer"] = None
+        self, layer: Optional[GlyphSet] = None
     ) -> Optional[BoundingBox]:
         """Returns the (xMin, yMin, xMax, yMax) bounding box of the glyph,
         taking only the control points into account.
@@ -425,7 +435,7 @@ class Glyph:
 
         return getControlBounds(self, layer)
 
-    def getLeftMargin(self, layer: Optional["Layer"] = None) -> Optional[float]:
+    def getLeftMargin(self, layer: Optional[GlyphSet] = None) -> Optional[float]:
         """Returns the the space in font units from the point of origin to the
         left side of the glyph.
 
@@ -438,7 +448,7 @@ class Glyph:
             return None
         return bounds.xMin
 
-    def setLeftMargin(self, value: float, layer: Optional["Layer"] = None) -> None:
+    def setLeftMargin(self, value: float, layer: Optional[GlyphSet] = None) -> None:
         """Sets the the space in font units from the point of origin to the
         left side of the glyph.
 
@@ -455,7 +465,7 @@ class Glyph:
             self.width += diff
             self.move((diff, 0))
 
-    def getRightMargin(self, layer: Optional["Layer"] = None) -> Optional[float]:
+    def getRightMargin(self, layer: Optional[GlyphSet] = None) -> Optional[float]:
         """Returns the the space in font units from the glyph's advance width
         to the right side of the glyph.
 
@@ -468,7 +478,7 @@ class Glyph:
             return None
         return self.width - bounds.xMax
 
-    def setRightMargin(self, value: float, layer: Optional["Layer"] = None) -> None:
+    def setRightMargin(self, value: float, layer: Optional[GlyphSet] = None) -> None:
         """Sets the the space in font units from the glyph's advance width to
         the right side of the glyph.
 
@@ -482,7 +492,7 @@ class Glyph:
             return None
         self.width = bounds.xMax + value
 
-    def getBottomMargin(self, layer: Optional["Layer"] = None) -> Optional[float]:
+    def getBottomMargin(self, layer: Optional[GlyphSet] = None) -> Optional[float]:
         """Returns the the space in font units from the bottom of the canvas to
         the bottom of the glyph.
 
@@ -498,7 +508,7 @@ class Glyph:
         else:
             return bounds.yMin - (self.verticalOrigin - self.height)
 
-    def setBottomMargin(self, value: float, layer: Optional["Layer"] = None) -> None:
+    def setBottomMargin(self, value: float, layer: Optional[GlyphSet] = None) -> None:
         """Sets the the space in font units from the bottom of the canvas to
         the bottom of the glyph.
 
@@ -520,7 +530,7 @@ class Glyph:
         if diff:
             self.height += diff
 
-    def getTopMargin(self, layer: Optional["Layer"] = None) -> Optional[float]:
+    def getTopMargin(self, layer: Optional[GlyphSet] = None) -> Optional[float]:
         """Returns the the space in font units from the top of the canvas to
         the top of the glyph.
 
@@ -536,7 +546,7 @@ class Glyph:
         else:
             return self.verticalOrigin - bounds.yMax
 
-    def setTopMargin(self, value: float, layer: Optional["Layer"] = None) -> None:
+    def setTopMargin(self, value: float, layer: Optional[GlyphSet] = None) -> None:
         """Sets the the space in font units from the top of the canvas to the
         top of the glyph.
 
